@@ -78,6 +78,8 @@ pub const RELOAD_INTERVALS_KEY: i32 = 14;
 pub const MAX_LOAD_KEY: i32 = 15;
 /// A key which tracks total value.
 pub const TOTAL_VALUE_KEY: i32 = 16;
+/// A key which tracks tour order statistics.
+pub const TOUR_ORDER_KEY: i32 = 17;
 
 mod pipeline;
 pub use self::pipeline::*;
