@@ -110,6 +110,7 @@ pub trait ConstraintModule {
 }
 
 /// Provides the way to work with multiple constraints.
+#[derive(Default)]
 pub struct ConstraintPipeline {
     /// Pipeline modules.
     pub modules: Vec<Arc<dyn ConstraintModule + Send + Sync>>,
@@ -125,19 +126,6 @@ pub struct ConstraintPipeline {
     pub soft_activity_constraints: Vec<Arc<dyn SoftActivityConstraint + Send + Sync>>,
 }
 
-impl Default for ConstraintPipeline {
-    fn default() -> Self {
-        ConstraintPipeline {
-            modules: vec![],
-            state_keys: Default::default(),
-            hard_route_constraints: vec![],
-            hard_activity_constraints: vec![],
-            soft_route_constraints: vec![],
-            soft_activity_constraints: vec![],
-        }
-    }
-}
-
 impl ConstraintPipeline {
     /// Accepts job insertion.
     pub fn accept_insertion(&self, solution_ctx: &mut SolutionContext, route_index: usize, job: &Job) {
