@@ -4,8 +4,8 @@ mod jobs_test;
 
 use crate::models::common::*;
 use crate::models::problem::{Costs, Fleet, TransportCost};
-use crate::utils::compare_floats;
 use hashbrown::HashMap;
+use rosomaxa::prelude::compare_floats;
 use std::cell::UnsafeCell;
 use std::cmp::Ordering::Less;
 use std::hash::{Hash, Hasher};
