@@ -18,5 +18,8 @@ pub use self::total_unassigned_jobs::TotalUnassignedJobs;
 mod total_value;
 pub use self::total_value::TotalValue;
 
+mod tour_order;
+pub use self::tour_order::TourOrder;
+
 mod work_balance;
 pub use self::work_balance::WorkBalance;
